@@ -5,6 +5,9 @@ from vtixy_proxy import settings
 class VTIXyProxyView(ProxyView):
     proxy_settings = settings.vtixy_uat_proxy_settings
 
+    def get_request_data(self, request):
+        return request.DATA
+
 
 class ShowsProxy(VTIXyProxyView):
     source = 'shows/'
